package
Version:
v0.4.1
Opens a new window with list of versions in this module.
Published: Jan 28, 2016
License: Apache-2.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type ExecError struct {
Name string `json:"name"`
Description string `json:"desc"`
}
ExecError is error resulted from application logic of plugin (e.g.
an exception thrown within a lambda function)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.